@@ -313,7 +313,6 @@ class textZone(sprite):
             print(matrix, self.fit_to_size())
 
         self.image.fill((0, 0, 0, 0))
-        self.image.fill((255, 0, 0, 100))
         # calcul positions
         x = 0
         y = 0
@@ -674,7 +673,9 @@ class ScrollableBox(sprite):
             _pos = py.Rect(_sprite.rect.left - self.rect.left, _sprite.rect.top - self.rect.top, *_sprite.rect.size)
             _object.blit(_sprite.image, _pos)
 
-        _surf.blit(self.cursor, (self.rect.width - self.cursor.get_width(), self.offset.y))
+        _offset = (1 - (self.rect.height / (self.rect.height + self.get_max())))
+        y = _offset * self.offset.y
+        _surf.blit(self.cursor, (self.rect.width - self.cursor.get_width(), y))
         _surf.blit(_object, (self.offset * -1)())
 
         return _surf
@@ -686,7 +687,9 @@ class ScrollableBox(sprite):
         _sprite = func()
         if sprite in _sprite.__class__.__bases__ or type(_sprite) == sprite:
             self.sprites.append(_sprite)
-            self.cursor = py.transform.scale(self.cursor, (self.cursor.get_width(), self.rect.height - self.get_max()))
+            factor = self.rect.height / (self.rect.height + self.get_max())
+            height = self.rect.height * factor
+            self.cursor = py.transform.scale(self.cursor, (self.cursor.get_width(), height))
         else:
             raise TypeError("You must return a sprite based class to add, type returned was :", type(_sprite))
 
